@@ -11,8 +11,6 @@ import shutil
 import time
 import urllib
 
-from base64 import b64encode, b64decode
-
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.policy import Policy
 from tiddlyweb.model.recipe import Recipe
@@ -185,9 +183,6 @@ class Store(StorageInterface):
             # (might be the same)
             tiddler.created = base_tiddler.modified
             tiddler.creator = base_tiddler.modifier
-            if (tiddler.type and tiddler.type != 'None' and not
-                    tiddler.type.startswith('text/')):
-                tiddler.text = b64decode(tiddler.text.lstrip().rstrip())
             return tiddler
         except IOError, exc:
             raise NoTiddlerError('no tiddler for %s: %s' %
@@ -225,9 +220,6 @@ class Store(StorageInterface):
         revision = self._tiddler_revision_filename(tiddler) + 1
         tiddler_filename = self._tiddler_full_filename(tiddler, revision)
 
-        if (tiddler.type and tiddler.type != 'None' and not
-                tiddler.type.startswith('text/')):
-            tiddler.text = b64encode(tiddler.text)
         self.serializer.object = tiddler
         write_utf8_file(tiddler_filename, self.serializer.to_string())
         write_unlock(tiddler_base_filename)
